#!/usr/bin/env python

from __future__ import print_function

import sys
import os
import string
import random
import optparse
import getpass
import time
sys.path.append(os.path.join(os.path.dirname(sys.path[0]), '..'))
from backup import *
from axicli import *

if __name__ == "__main__":

    parser = optparse.OptionParser(description = 'Axigen backup utility.',\
                                   version = 'Axigen restore version 1.1',\
                                   usage = '%prog [options] <mount dir> <backup dir>')
    parser.add_option('-H', '--host', default = 'localhost', help = 'axigen cli service host name (default: <localhost>')
    parser.add_option('-p', '--port', type = 'int', default = 7000, help = 'axigen cli service port (default: 7000)')
    parser.add_option('-u', '--user', default = 'admin', help = 'axigen cli login user name (default: <admin>)')
    parser.add_option('-P', '--password', help = 'axigen cli login password')
    #parser.add_option('mountDir', help = 'FUSE mount directory')
    #parser.add_option('backupDir', help = 'Backup directory')

    (options, args) = parser.parse_args()

    if len(args) != 2:
        parser.print_usage()
        sys.exit(2)

    if options.password == None:
        options.password = getpass.getpass(\
            "Enter password for {0}@{1}".format(options.user, options.host))
    
    destDir = os.path.realpath(args[0])
    if os.path.exists(destDir):
        if not os.path.isdir(destDir):
            print("Destination path must be an empty directory")
            sys.exit(1)
        if os.listdir(destDir):
            print("Destination directory not empty")
            sys.exit(1)
    else:
        destDir = args[0]

    srcDir = os.path.realpath(args[1])
    if not os.path.exists(srcDir):
        print("Source directory not found")
        sys.exit(1)
    if not os.path.isdir(srcDir):
        print("Source path must be a directory")
        sys.exit(1)
        
    try:
        cliConn = cliconnection.Connection(options.user, options.password, options.host, options.port)
        cliConn.login()
        clicommand.ConfigCommand("server").execute(cliConn)
        clicommand.ConfigCommand("ftp-backup").execute(cliConn)
        clicommand.SimpleCommand("filesystem mount {0}".format(destDir)).execute(cliConn)
        cliConn.logout()
        del cliConn
    except:
        print("Error mounting axigen backup filesystem:", sys.exc_info())
        sys.exit(3)

    time.sleep(1)
    bkResult = False
    axiDir = os.path.join(destDir, "domains")
    if not os.path.isdir(axiDir):
        print("Unable to mount axigen backup filesystem")
    else:
        bkeng = None
        try:
            bkeng = bkengine.Engine(srcDir, axiDir)
            cpi = bkreporter.getProgressIndicator()
            bkeng.registerProgressIndicator(cpi)
            bkResult = bkeng.restore()
        except:
            print("Unhandled exception during backup:", sys.exc_info()[0])
            bkResult = False
        del bkeng
        os.closerange(3, 128)

    try:
        cliConn = cliconnection.Connection(options.user, options.password, options.host, options.port)
        cliConn.login()
        clicommand.ConfigCommand("server").execute(cliConn)
        clicommand.ConfigCommand("ftp-backup").execute(cliConn)
        clicommand.SimpleCommand("filesystem unmount {0}".format(destDir)).execute(cliConn)
        cliConn.logout()
        del cliConn
    except:
        print("Error unmounting axigen backup filesystem:", sys.exc_info()[0])
    
    if not bkResult:
        sys.exit(3)
    sys.exit(0)
    
